==> rekor_1.4.2.orig.tar.xz: rekor-1.4.2/pkg/types/intoto/v0.0.2/benchmark_test.go <==
//
// Copyright 2025 The Sigstore Authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package intoto

import (
	"testing"

	"github.com/go-openapi/strfmt"
	"github.com/sigstore/rekor/pkg/generated/models"
	"github.com/sigstore/rekor/pkg/types"
)

// Sample test data for benchmarking
var sampleIntotoV002Data = map[string]any{
	"content": map[string]any{
		"envelope": map[string]any{
			"payload":     "dGVzdA==",
			"payloadType": "application/vnd.in-toto+json",
			"signatures": []map[string]any{
				{
					"keyid":     "test-key-1",
					"sig":       "dGVzdFNpZ25hdHVyZTE=",
					"publicKey": "dGVzdFB1YmxpY0tleTF=",
				},
				{
					"keyid":     "test-key-2",
					"sig":       "dGVzdFNpZ25hdHVyZTI=",
					"publicKey": "dGVzdFB1YmxpY0tleTI=",
				},
			},
		},
		"hash": map[string]any{
			"algorithm": "sha256",
			"value":     "abc123",
		},
		"payloadHash": map[string]any{
			"algorithm": "sha256",
			"value":     "def456",
		},
	},
}

// BenchmarkDecodeEntryMapstructure benchmarks the original mapstructure-based DecodeEntry
func BenchmarkDecodeEntryMapstructure(b *testing.B) {
	for b.Loop() {
		var intotoObj models.IntotoV002Schema
		err := types.DecodeEntry(sampleIntotoV002Data, &intotoObj)
		if err != nil {
			b.Fatalf("DecodeEntry failed: %v", err)
		}

		// Validate the result to ensure it's properly decoded
		if err := intotoObj.Validate(strfmt.Default); err != nil {
			b.Fatalf("Validation failed: %v", err)
		}
	}
}

// BenchmarkDecodeEntryDirect benchmarks the new direct JSON unmarshaling method
func BenchmarkDecodeEntryDirect(b *testing.B) {
	for b.Loop() {
		entry := &V002Entry{}
		err := DecodeEntry(sampleIntotoV002Data, &entry.IntotoObj)
		if err != nil {
			b.Fatalf("DecodeEntryDirect failed: %v", err)
		}

		// Validate the result to ensure it's properly decoded
		if err := entry.IntotoObj.Validate(strfmt.Default); err != nil {
			b.Fatalf("Validation failed: %v", err)
		}
	}
}

// BenchmarkDecodeEntryMapstructureMemory benchmarks memory allocation for mapstructure
func BenchmarkDecodeEntryMapstructureMemory(b *testing.B) {
	b.ReportAllocs()
	for b.Loop() {
		var intotoObj models.IntotoV002Schema
		err := types.DecodeEntry(sampleIntotoV002Data, &intotoObj)
		if err != nil {
			b.Fatalf("DecodeEntry failed: %v", err)
		}
	}
}

// BenchmarkDecodeEntryDirectMemory benchmarks memory allocation for direct method
func BenchmarkDecodeEntryDirectMemory(b *testing.B) {
	b.ReportAllocs()
	for b.Loop() {
		entry := &V002Entry{}
		err := DecodeEntry(sampleIntotoV002Data, &entry.IntotoObj)
		if err != nil {
			b.Fatalf("DecodeEntryDirect failed: %v", err)
		}
	}
}

==> rekor_1.4.3.orig.tar.xz: rekor-1.4.3/pkg/types/intoto/v0.0.1/benchmark_test.go <==
//
// Copyright 2025 The Sigstore Authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package intoto

import (
	"testing"

	"github.com/go-openapi/strfmt"
	"github.com/sigstore/rekor/pkg/generated/models"
	"github.com/sigstore/rekor/pkg/types"
)

// Sample test data for benchmarking
var sampleIntotoV001Data = map[string]any{
	"content": map[string]any{
		"envelope": `{"_type":"https://in-toto.io/Statement/v0.1","predicateType":"https://slsa.dev/provenance/v0.2","subject":[{"name":"test","digest":{"sha256":"abc123"}}],"predicate":{"builder":{"id":"test-builder"}}}`,
		"hash": map[string]any{
			"algorithm": "sha256",
			"value":     "abc123",
		},
		"payloadHash": map[string]any{
			"algorithm": "sha256",
			"value":     "def456",
		},
	},
	"publicKey": "dGVzdFB1YmxpY0tleQ==",
}

// BenchmarkDecodeEntryMapstructure benchmarks the original mapstructure-based DecodeEntry
func BenchmarkDecodeEntryMapstructure(b *testing.B) {
	for b.Loop() {
		var intotoObj models.IntotoV001Schema
		err := types.DecodeEntry(sampleIntotoV001Data, &intotoObj)
		if err != nil {
			b.Fatalf("DecodeEntry failed: %v", err)
		}

		// Validate the result to ensure it's properly decoded
		if err := intotoObj.Validate(strfmt.Default); err != nil {
			b.Fatalf("Validation failed: %v", err)
		}
	}
}

// BenchmarkDecodeEntryDirect benchmarks the new direct JSON unmarshaling method
func BenchmarkDecodeEntryDirect(b *testing.B) {
	for b.Loop() {
		entry := &V001Entry{}
		err := DecodeEntry(sampleIntotoV001Data, &entry.IntotoObj)
		if err != nil {
			b.Fatalf("DecodeEntryDirect failed: %v", err)
		}

		// Validate the result to ensure it's properly decoded
		if err := entry.IntotoObj.Validate(strfmt.Default); err != nil {
			b.Fatalf("Validation failed: %v", err)
		}
	}
}

// BenchmarkDecodeEntryMapstructureMemory benchmarks memory allocation for mapstructure
func BenchmarkDecodeEntryMapstructureMemory(b *testing.B) {
	b.ReportAllocs()
	for b.Loop() {
		var intotoObj models.IntotoV001Schema
		err := types.DecodeEntry(sampleIntotoV001Data, &intotoObj)
		if err != nil {
			b.Fatalf("DecodeEntry failed: %v", err)
		}
	}
}

// BenchmarkDecodeEntryDirectMemory benchmarks memory allocation for direct method
func BenchmarkDecodeEntryDirectMemory(b *testing.B) {
	b.ReportAllocs()
	for b.Loop() {
		entry := &V001Entry{}
		err := DecodeEntry(sampleIntotoV001Data, &entry.IntotoObj)
		if err != nil {
			b.Fatalf("DecodeEntryDirect failed: %v", err)
		}
	}
}
